<?php

/**
 * This is the model class for table "formdata".
 *
 * The followings are the available columns in table 'formdata':
 * @property string $id
 * @property string $form_id
 * @property string $created_at
 * @property string $referer
 * @property string $ip
 * @property string $json
 */
class FGFormdata extends CActiveRecord
{
	/**
	 * Returns the static model of the specified AR class.
	 * @param string $className active record class name.
	 * @return FGFormdata the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'formdata';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('form_id, json', 'required'),
			array('referer', 'length', 'max'=>2083),
			array('ip', 'length', 'max'=>15),
			array('created_at', 'safe'),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('id, form_id, created_at, referer, ip, json', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'form' => array(self::BELONGS_TO, 'FGForms', 'form_id')
		);
	}
	
	public function scopes()
	{
		return array(
		);
	}
	
	public function defaultScope()
	{
		return array('order'=>'id DESC');
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'form_id' => 'Form',
			'created_at' => 'Created At',
			'referer' => 'Referer',
			'ip' => 'Ip',
			'json' => 'Json',
		);
	}
	
	public function JSONToArray()
	{
		return CJSON::decode($this->json);
	}
	
	public function getDisplayData()
	{
		$data = $this->JSONToArray();
		$display = array();
		foreach($data as $name => $value) {
			/* Temporary cap */
			$display[$name] = is_array($value)? implode("<br />", $value) : CHtml::encode($value);
		}
		return $display;
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id,true);
		$criteria->compare('form_id',$this->form_id,true);
		$criteria->compare('created_at',$this->created_at,true);
		$criteria->compare('referer',$this->referer,true);
		$criteria->compare('ip',$this->ip,true);
		$criteria->compare('json',$this->json,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}
}