<?php
/**
 * Gentics Portal.Node PHP
 * Author & Copyright (c) by Gentics Software GmbH
 * sales@gentics.com
 * http://www.gentics.com
 * Licenses can be found in the LICENSE.txt file in the root-folder of this installation
 * You must not use this software without a valid license agreement.
 *
 *
 * Shows user search result. Use in pair with FriendsSearchWidget
 */
class FriendsSearchResultWidget extends BaseWidget
{

    private $_friendships = array();

    public function run()
    {
        $models = $this->_getPreparedModels();
        if (!empty($models['UserSearch']) || !empty($models['Profile'])) {
            $criteria = new CDbCriteria;
            $criteria->compare('status', User::STATUS_ACTIVE);

            if (isset($models['UserSearch'])) {
                $user = new UserSearch();
                $user->attributes = $models['UserSearch'];
                $user->validate();
                foreach ($models['UserSearch'] as $name => $value) {
                    if (!$user->hasErrors($name) && $value == $user->$name) {
                        $criteria->compare($name, $value, true);
                    }
                }
                if (!Yii::app()->user->isGuest) {
                    $criteria->addCondition('id != :id');
                    $criteria->params[':id'] = Yii::app()->user->id;
                }
            }

            $profile = new Profile();
            if(!isset($profile->phone)){
                $alter_phone = "ALTER TABLE {{profiles}} ADD `phone` varchar(255) NOT NULL DEFAULT '+43'";
                Yii::app()->db->createCommand($alter_phone)->execute();

            }
            if (isset($models['Profile'])) {
                $profile->attributes = $models['Profile'];
                $profile->validate();
                $criteria->together = true;
                $criteria->with = array('profile');
                foreach ($models['Profile'] as $name => $value) {
                    if (!$profile->hasErrors($name) && $value == $profile->$name) {
                        $criteria->compare("profile.$name", $value, true);
                    }
                }
            }
            if ($profile->hasAttribute('find_me_in_phone_book')) {
                $criteria->compare("profile.find_me_in_phone_book", true);
            }
            $dataProvider = new CActiveDataProvider('User', array(
                'criteria' => $criteria,
                'pagination' => array( //                'pageSize' => $this->module->user_list_page_size,
                ),
            ));

            if (!Yii::app()->user->isGuest) {
                $this->_friendships = Friendship::model()->findAll('user1_id = :user_id or user2_id = :user_id', array(':user_id' => Yii::app()->user->id));
            }
        } else {
            $dataProvider = null;
        }

        $this->render('FriendsSearchResultWidget', array('dataProvider' => $dataProvider));
    }

    private function _getPreparedModels()
    {
        $preparedModels = array();
        foreach (array('UserSearch', 'Profile') as $model) {
            if (isset($_GET[$model])) {
                $preparedModels[$model] = array_filter($_GET[$model], function ($var) {
                    $var = trim($var);
                    return !empty($var);
                });
            }
        }
        return $preparedModels;
    }

    public function friendshipStatus($user)
    {
        foreach ($this->_friendships as $f) {
            if ($f->user1_id == $user->id || $f->user2_id == $user->id) {
                if ($f->status == Friendship::STATUS_APPROVED) {
                    return 'friends';
                } else {
                    return 'waiting';
                }
            }
        }

        return 'not friends';
    }


}
