<?php

/**
 * Gentics Portal.Node PHP
 * Author & Copyright (c) by Gentics Software GmbH
 * sales@gentics.com
 * http://www.gentics.com
 * Licenses can be found in the LICENSE.txt file in the root-folder of this installation
 * You must not use this software without a valid license agreement.
 *
 * This is the model class for table "{{item}}".
 *
 * The followings are the available columns in table '{{item}}':
 * @property string $id
 * @property double $price
 * @property string $admin_email
 * @property string $page_id
 * @property string $title
 * @property string $item_id
 * @property string $order_id
 * @property string $quantity
 * @property string $referrer
 * @property string $ip_address
 * @property string $ordered_at
 * @property string $item_referrer
 */
class Item extends CActiveRecord
{
	/**
	 * Returns the static model of the specified AR class.
	 * @param string $className active record class name.
	 * @return Item the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
	
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return '{{item}}';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('admin_email, title, referrer, ip_address, page_id, item_id', 'required'),
            array('page_id, item_id','numerical', 'integerOnly' => true),
			array('price, quantity', 'numerical'),
            array('quantity','compare','operator'=>'>','compareValue'=>(-1)),
            array('price','compare','operator'=>'>','compareValue'=>(-1)),
			array('admin_email, title, referrer, item_referrer', 'length', 'max'=>255),
			array('page_id, item_id, order_id, quantity', 'length', 'max'=>10),
			array('ip_address', 'length', 'max'=>16),
			array('ordered_at', 'safe'),
            array('admin_email','email'),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('id, price, admin_email, page_id, title, item_id, order_id, quantity, referrer, ip_address, ordered_at', 'safe', 'on'=>'search'),
        );
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
            'order' => array(self::BELONGS_TO, 'Order', 'order_id'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => ShoppingcartModule::t('ID'),
			'price' => ShoppingcartModule::t('Price'),
			'admin_email' => ShoppingcartModule::t('Admin Email'),
			'page_id' => ShoppingcartModule::t('Page'),
			'title' => ShoppingcartModule::t('Title'),
			'item_id' => ShoppingcartModule::t('Item'),
			'order_id' => ShoppingcartModule::t('Order'),
			'quantity' => ShoppingcartModule::t('Quantity'),
			'referrer' => ShoppingcartModule::t('Referrer'),
			'ip_address' => ShoppingcartModule::t('Ip Address'),
			'ordered_at' => ShoppingcartModule::t('Ordered At'),
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id,true);
		$criteria->compare('price',$this->price);
		$criteria->compare('admin_email',$this->admin_email,true);
		$criteria->compare('page_id',$this->page_id,true);
		$criteria->compare('title',$this->title,true);
		$criteria->compare('item_id',$this->item_id,true);
		$criteria->compare('order_id',$this->order_id,true);
		$criteria->compare('quantity',$this->quantity,true);
		$criteria->compare('referrer',$this->referrer,true);
		$criteria->compare('ip_address',$this->ip_adsress,true);
		$criteria->compare('ordered_at',$this->ordered_at,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}
    /**
     * Returns the price with currency in the correct local format
     *
     * @param string $price the price that you want to attach currency
     *
     * @return string price with currency
     */
    public static function addCurrency($price){
        $currency =  Yii::app()->getModule('shoppingcart')->currency;
        return Yii::app()->numberFormatter->formatCurrency($price, $currency);
    }

    /**
     * Function to get checksum of fields
     *
     * @param object $model instance of Item class
     * @param boolean $encrypted flag that shows when fields of instance are encrypted
     *
     * @return checksum of fields
     */
    public  function getItemChecksum($encrypted = false){
        $fields = array('item_id','title','price','page_id','admin_email');
        $str= '';
        foreach($fields as $field){
            $str.= $encrypted? EncryptHelper::decrypt($this->$field):$this->$field;
        }
        return  md5($str);
    }
}