<?php
/**
 * Gentics Portal.Node PHP
 * Author & Copyright (c) by Gentics Software GmbH
 * sales@gentics.com
 * http://www.gentics.com
 * Licenses can be found in the LICENSE.txt file in the root-folder of this installation
 * You must not use this software without a valid license agreement.
 *
 */
class ShortUrlController extends BaseController
{
    /**
     * Action for redirecting to a DCR page by short URL
     * @param type $type p for pages or f for files
     * @param type $encodedId The base encoded object ID
     * @throws CHttpException When DynamicContentSource is not enabled or the
     *         content ID doesn't exist
     */
    public function actionRedirect($type, $encodedId)
    {
        $contentSourceModule = Yii::app()->getModule('contentSource');

        if ($contentSourceModule instanceof FileSystemContentSource) {
            throw new CHttpException(404, "No short URLs for FSCRs");
        }

        $contentId = Yii::app()->getModule('shorturl')->transformToContentId($type, $encodedId);
        $content = $contentSourceModule->getContentById($contentId);

        if (!$content) {
            // This content ID does not exist
            throw new CHttpException(404, "The content ID " . $contentId . " doesn't exist");
        }

        $path = $content->getPath();

        $this->redirect($path);
    }
}
